# Clock Domain Crossing

The {py:mod}`torii.lib.cdc` module provides building blocks for transferring data between clock domains.

```{eval-rst}

.. autoclass:: torii.lib.cdc.FFSynchronizer
.. autoclass:: torii.lib.cdc.AsyncFFSynchronizer
.. autoclass:: torii.lib.cdc.ResetSynchronizer
.. autoclass:: torii.lib.cdc.PulseSynchronizer

```
